@@ -13,6 +13,7 @@ from vdb.lib import db as dbLib
 from vdb.lib.gha import GitHubSource
 from vdb.lib.npm import NpmSource
 from vdb.lib.nvd import NvdSource
+from vdb.lib.osv import OSVSource
 
 logging.basicConfig(
     level=logging.INFO, format="%(levelname)s [%(asctime)s] %(message)s"
@@ -52,6 +53,13 @@ def build_args():
         dest="cache",
         help="Cache vulnerability information in platform specific user_data_dir",
     )
+    parser.add_argument(
+        "--only-osv",
+        action="store_true",
+        default=False,
+        dest="only_osv",
+        help="Use only OSV as the source.",
+    )
     parser.add_argument(
         "--sync",
         action="store_true",
@@ -146,11 +154,12 @@ def main():
                 os.rmdir(config.data_dir)
             except Exception:
                 pass
-    else:
-        LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
-
     if args.cache:
-        for s in [GitHubSource(), NvdSource()]:
+        if args.only_osv:
+            sources = [OSVSource()]
+        else:
+            sources = [OSVSource(), GitHubSource(), NvdSource()]
+        for s in sources:
             LOG.info("Refreshing {}".format(s.__class__.__name__))
             s.refresh()
     elif args.sync:
@@ -174,6 +183,7 @@ def main():
         results = dbLib.list_all_occurrence(db)
         print_results(results)
     elif args.search:
+        LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
         db = dbLib.get()
         search_list = re.split(r"[,|;]", args.search)
         for pkg_info in search_list:
