@@ -15,12 +15,16 @@ KNOWN_PKG_TYPES = [
     "rubygems",
     "golang",
     "crates",
+    "clojars",
+    "conan",
+    "pub",
+    "hackage",
 ]
 
 # Maps variations of string to package types
 PKG_TYPES_MAP = {
     "composer": ["php", "laravel", "wordpress", "joomla"],
-    "maven": ["jenkins", "java", "kotlin", "groovy"],
+    "maven": ["jenkins", "java", "kotlin", "groovy", "clojars", "hackage"],
     "npm": ["javascript", "node.js", "nodejs"],
     "nuget": [".net_framework", "csharp", ".net_core", "asp.net"],
     "pypi": ["python"],
