@@ -116,8 +116,15 @@ class OSVSource(NvdSource):
             assigner = "cve@mitre.org"
         elif cve_id.startswith("NPM"):
             assigner = "@npm"
+        severity = "LOW"
+        # Issue 58
+        cve_database_specific = cve_data.get("database_specific")
+        cve_ecosystem_specific = cve_data.get("ecosystem_specific")
+        if cve_database_specific and cve_database_specific.get("severity"):
+            severity = cve_database_specific.get("severity")
+        if cve_ecosystem_specific and cve_ecosystem_specific.get("severity"):
+            severity = cve_ecosystem_specific.get("severity")
         for pkg_data in cve_data.get("affected"):
-            severity = "LOW"
             if pkg_data.get("ecosystem_specific"):
                 ecosystem_specific = pkg_data.get("ecosystem_specific")
                 if ecosystem_specific.get("severity"):
@@ -126,7 +133,7 @@ class OSVSource(NvdSource):
                 database_specific = pkg_data.get("database_specific")
                 if database_specific.get("cwes"):
                     cwes = database_specific.get("cwes")
-                    if cwes:
+                    if isinstance(cwes, list):
                         cwe_id = cwes[0].get("cweId")
                 if database_specific.get("cvss"):
                     cvss = database_specific.get("cvss")
