@@ -3,6 +3,7 @@ import re
 from datetime import date, datetime
 from enum import Enum
 
+from packageurl import PackageURL
 from semver import VersionInfo
 
 from vdb.lib import CPE_FULL_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
@@ -613,3 +614,42 @@ def convert_md_references(md_text):
                 {"name": parts[0].replace("[", ""), "url": parts[1].replace(")", "")}
             )
     return ref_list
+
+
+def parse_purl(purl_str):
+    """Method to parse a package url string safely"""
+    try:
+        return PackageURL.from_string(purl_str).to_dict() if purl_str else None
+    except ValueError:
+        tmpA = purl_str.split("@")[0]
+        purl_obj = {}
+        if tmpA:
+            tmpB = tmpA.split("/")
+            if tmpB:
+                if len(tmpB) < 2:
+                    purl_obj["name"] = tmpB[-1].lower()
+                    purl_obj["namespace"] = tmpB[0].split(":")[-1]
+                if len(tmpB) > 2:
+                    namespace = tmpB[-2]
+                    if tmpB[-2].startswith("pkg:"):
+                        namespace = tmpB[-2].split(":")[-1]
+                    purl_obj["namespace"] = namespace
+        return purl_obj
+
+
+def convert_score_severity(score):
+    """Convert numeric score to severity string"""
+    if not score:
+        return "LOW"
+    try:
+        score = float(score)
+        if score < 4:
+            return "LOW"
+        elif score < 7:
+            return "MEDIUM"
+        elif score < 9:
+            return "HIGH"
+        else:
+            return "CRITICAL"
+    except ValueError:
+        return "LOW"
